@@ -141,6 +141,20 @@ class Fs_lcr_rate_class extends Safe_configurable_object_class
                 $line++;
             }
             fclose($handle);
+            // check if we have header checked set and some lines
+            if(!$header_checked){
+                $error_messages[]= array(
+                        'message' =>  'Invalid CSV header, must be: '.implode(',', $keys)
+                );
+                $rc = false;
+            }
+            if(!$line){
+                $error_messages[]= array(
+                        'message' =>  'Empty CSV file.',
+                );
+                $rc = false;
+            }
+
         }else{
             $error_messages[]= array(
                     'message' => "Fail to open ".$file,
@@ -163,14 +177,12 @@ class Fs_lcr_rate_class extends Safe_configurable_object_class
             $count = 0;
             if(!$this->_validate_csv($conf.'/'.$this->name(), $count, $out_message)){
                 @unlink($conf.'/'.$this->name());
-                error_log(print_r($out_message, true));
                 return false;
             }
             $data['count'] = $count;
         }
 
         $this->set_data_values($data);
-        error_log(print_r($data, true));
         return parent::validate($data, $out_message);
     }
     public function download(){
