@@ -774,6 +774,19 @@ class Safe_object_class
         error_log("WARNING - Cannot retrieve aggregate_object ${type} for module ".$this->name());
         return array();
     }
+    public function get_aggregate_object($type, $name, $all=false)
+    {
+        // Request a specific object by name (and type)
+        // Lazy implementation ask for all objs and return by key
+        $objs = $this->get_aggregate_objects($type, $all);
+        return $objs[$name];
+    }
+    public function get_aggregate_objects_keys($type, $all = false)
+    {
+        // Default lazy implementation, ask for objects than extract keys
+        $objs = $this->get_aggregate_objects($type, $all);
+        return array_keys($objs);
+    }
     
     /**
      * @brief clear objs in cache (so it can be regenerate from db )
@@ -805,8 +818,8 @@ class Safe_object_class
     public function can_create_aggregate_object($type, $name, &$reason="")
     {
         // Default implementation - Check object name exists
-        $objs = $this->get_aggregate_objects($type);
-        if($objs[$name]){
+        $obj_keys = $this->get_aggregate_objects_keys($type);
+        if(in_array($name, $obj_keys)){
             $reason = "Already exists";
             return false;
         }else{
@@ -914,11 +927,20 @@ class Safe_object_class
     {
         $obj_def = $this->get_aggregate_object_definition($type);
         $label = 'New ' . $obj_def['name'];
-        $number = count($this->get_aggregate_objects($type))+1;
+        $keys = $this->get_aggregate_objects_keys($type);
+        $number = count($keys)+1;
         $new_name = ucfirst($type) . $number;
+        while(in_array($new_name, $keys)){
+            $number++;
+            $new_name = ucfirst($type) . $number;
+        };
         $config_manager->add_field('profile-name', $label, 'string', $new_name, 50);
         $config_manager->set_field_rules('profile-name', 'required|alpha_dash');
     }
+    public function build_unique_name($type)
+    {
+        return Safe_object_serializer_class::build_unique_name($type);
+    }
 
     /**
      * @brief Populate auditor with audit point for object
@@ -931,6 +953,11 @@ class Safe_object_class
     {
         return true;
     }
+    public function download(){
+        header('HTTP/1.0 501 Not Implemented'); 
+        exit();
+    }
+    
 }
 abstract class Safe_serializable_object_class extends Safe_object_class
 {
@@ -1678,7 +1705,7 @@ class Safe_configurable_object_class extends Safe_serializable_object_class
         }
         return $values;
     }
-    public function get_data_values_with_field_desc($resolve_enum = true, $include_hidden = true, $include_password = true)
+    public function get_data_values_with_field_desc($resolve_enum = true, $include_hidden = true, $include_password = true, $include_base64=true)
     {
         $values = array();
         // walk data and strip keys, just keep values
@@ -1689,6 +1716,9 @@ class Safe_configurable_object_class extends Safe_serializable_object_class
             if (!$include_password && $v['type'] == 'password'){
                 continue;
             }
+            if (!$include_base64 && $v['type'] == 'base64'){
+                continue;
+            }
             if (!isset($v['value']) || false == $resolve_enum){
                 $values[$v['label']] = $v['default'];
             }else{
@@ -1721,7 +1751,7 @@ class Safe_configurable_object_class extends Safe_serializable_object_class
     }
     public function summary($type = 'horizontal' , $long = false, $min=3)
     {
-        $list =  $this->get_data_values_with_field_desc(true, false, false);
+        $list =  $this->get_data_values_with_field_desc(true, false, false, false);
         if($long){
             array_unshift($list,array('Name' => $this->name()));
             return array( 'data' => $list);
@@ -1895,6 +1925,5 @@ class Safe_configurable_object_class extends Safe_serializable_object_class
     public function set_form_error($field = '', $message = ''){
         $this->_form->set_error($field , $message);
     }
-    
 }
 /* End of file safe_object_class.php */
