@@ -284,9 +284,6 @@ class Sng_network_service_class extends Safe_service_class
     public function api_create_route($name, $data=null, &$output = null) {
         $route = new Sng_network_route_class($this->node(), $this->object_name().'/route', $name);
         $route->configure();
-        if($data) {
-            $route->set_data_values($data);
-        }
         return $route;
     }
     /**
@@ -323,7 +320,9 @@ class Sng_network_service_class extends Safe_service_class
         // update as usual (ie. status == NEW)
         $route = $this->api_retrieve_route($name);
         if($route) {
-            return $route->save();
+            if ($route->validate($data,$output)) {
+                return $route->save($output);
+            }
         }
         return false;
     }
